@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -58,17 +59,18 @@ protected:
             , mEnableFromUserSettings(false)
         {
         }
+
         QString mIdentifier;
         QString mDescription;
         bool mEnableByDefault;
         bool mHasConfigureSupport;
         bool mEnableFromUserSettings;
     };
-    void savePlugins(const QString &groupName, const QString &prefixSettingKey, const QList<PluginItem *> &listItems);
-    void fillTopItems(const QVector<PimCommon::PluginUtilData> &lst, const QString &topLevelItemName, const QString &groupName, const QString &prefixKey, QList<PluginItem *> &itemsList,
-                      const QString &configureGroupName = QString());
-    void resetToUserSettings(const QList<PluginItem *> &items);
-    void changeState(const QList<PluginItem *> &items);
+    void savePlugins(const QString &groupName, const QString &prefixSettingKey, const QVector<PluginItem *> &listItems);
+    void fillTopItems(const QVector<PimCommon::PluginUtilData> &lst, const QString &topLevelItemName, const QString &groupName, const QString &prefixKey, QVector<PluginItem *> &itemsList,
+                      const QString &configureGroupName = QString(), bool checkable = true);
+    void resetToUserSettings(const QVector<PluginItem *> &items);
+    void changeState(const QVector<PluginItem *> &items);
 
     QTreeWidget *mListWidget = nullptr;
 private:
