@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -28,21 +29,21 @@ class PIMCOMMON_EXPORT MigrateFileInfo
 public:
     MigrateFileInfo();
 
-    QString type() const;
+    Q_REQUIRED_RESULT QString type() const;
     void setType(const QString &type);
 
-    QString path() const;
+    Q_REQUIRED_RESULT QString path() const;
     void setPath(const QString &path);
 
-    bool folder() const;
+    Q_REQUIRED_RESULT bool folder() const;
     void setFolder(bool folder);
 
-    bool isValid() const;
+    Q_REQUIRED_RESULT bool isValid() const;
 
-    int version() const;
+    Q_REQUIRED_RESULT int version() const;
     void setVersion(int version);
 
-    QStringList filePatterns() const;
+    Q_REQUIRED_RESULT QStringList filePatterns() const;
     void setFilePatterns(const QStringList &filePatterns);
 
 private:
