@@ -30,10 +30,6 @@ PurposeMenuWidgetTest::PurposeMenuWidgetTest(QObject *parent)
 void PurposeMenuWidgetTest::shouldHaveDefaultValues()
 {
     TestMenu w(nullptr);
-#ifdef KF5_USE_PURPOSE
     QVERIFY(w.menu());
     QCOMPARE(w.menu()->objectName(), QStringLiteral("purposesharemenu"));
-#else
-    QVERIFY(!w.menu());
-#endif
 }
