@@ -43,7 +43,7 @@ public:
     Q_DECLARE_FLAGS(RequireTypes, RequireType)
 
     void setActionTypes(const QVector<ActionType> &type);
-    void addActionType(const ActionType &type);
+    void addActionType(ActionType type);
     Q_REQUIRED_RESULT QVector<ActionType> actionTypes() const;
 
     virtual void setCurrentItems(const Akonadi::Item::List &items);
